@@ -4,3 +4,6 @@ __author__ = 'jasonxu'
 from cthun_client.client import Client
 from cthun_client.config import Config
 from cthun_client.connection import Connection
+from cthun_client.device.ios import Ios
+from cthun_client.device.android import Android
+
